summary refs log tree commit diff stats
path: root/lib/pure/strformat.nim
diff options
context:
space:
mode:
authorArne Döring <arne.doering@gmx.net>2018-04-15 19:59:11 +0200
committerAndreas Rumpf <rumpf_a@web.de>2018-04-15 19:59:11 +0200
commitefae3668570b51fa14483663d1979a6a8a6852fe (patch)
tree6db0ac8604f30ceb67b2689b3ab37263dc225b62 /lib/pure/strformat.nim
parentb98cd3bf348a41778f475e835b86ab9175125789 (diff)
downloadNim-efae3668570b51fa14483663d1979a6a8a6852fe.tar.gz
rename SomeReal to SomeFloat (#7617)
* rename SomeReal to SomeFloat
* added changelog entry
Diffstat (limited to 'lib/pure/strformat.nim')
-rw-r--r--lib/pure/strformat.nim8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/pure/strformat.nim b/lib/pure/strformat.nim
index 421e5e683..abdb655d7 100644
--- a/lib/pure/strformat.nim
+++ b/lib/pure/strformat.nim
@@ -375,7 +375,7 @@ type
                       ## ``parseStandardFormatSpecifier`` returned.
 
 proc formatInt(n: SomeNumber; radix: int; spec: StandardFormatSpecifier): string =
   ## Converts ``n`` to string. If ``n`` is `SomeReal`, it casts to `int64`.
   ## Conversion is done using ``radix``. If result's length is lesser than
   ## ``minimumWidth``, it aligns result to the right or left (depending on ``a``)
   ## with ``fill`` char.
@@ -503,8 +503,8 @@ proc format*(value: SomeInteger; specifier: string; res: var string) =
       " of 'x', 'X', 'b', 'd', 'o' but got: " & spec.typ)
   res.add formatInt(value, radix, spec)
 
-proc format*(value: SomeReal; specifier: string; res: var string) =
-  ## Standard format implementation for ``SomeReal``. It makes little
+proc format*(value: SomeFloat; specifier: string; res: var string) =
+  ## Standard format implementation for ``SomeFloat``. It makes little
   ## sense to call this directly, but it is required to exist
   ## by the ``&`` macro.
   let spec = parseStandardFormatSpecifier(specifier)
@@ -678,4 +678,4 @@ when isMainModule:
 
   doAssert fmt"{'a'} {'b'}" == "a b"
 
-  echo("All tests ok")
\ No newline at end of file
+  echo("All tests ok")
@@ -375,7 +375,7 @@ type
 
 proc formatInt(n: SomeNumber; radix: int; spec: StandardFormatSpecifier): string =
-  ## Converts ``n`` to string. If ``n`` is `SomeReal`, it casts to `int64`.
+  ## Converts ``n`` to string. If ``n`` is `SomeFloat`, it casts to `int64`.
   ## Conversion is done using ``radix``. If result's length is lesser than
   ## ``minimumWidth``, it aligns result to the right or left (depending on ``a``)